@@ -218,7 +218,9 @@ describe("failures", function () {
     expect(obj.code).to.equal(1);
     expect(obj.stderr).to.contain(`Hit ${NUM_ERRS} errors`);
 
-    const exps = Array(NUM_ERRS).fill("Error: SYNC");
+    // Webpack5 has "inner" repeat traces of error.
+    const WEBPACK_5_EXTRAS = 1;
+    const exps = Array(NUM_ERRS + WEBPACK_5_EXTRAS).fill("Error: SYNC");
     const errs = obj.stderr.match(/(^Error\: SYNC)/gm);
     expect(errs).to.eql(exps);
   });
@@ -237,12 +239,37 @@ describe("failures", function () {
     expect(obj.code).to.equal(1);
     expect(obj.stderr).to.contain(`Hit ${NUM_ERRS} errors`);
 
-    const exps = Array(NUM_ERRS).fill("Error: PROMISE");
+    // Webpack5 has "inner" repeat traces of error.
+    const WEBPACK_5_EXTRAS = 1;
+    const exps = Array(NUM_ERRS + WEBPACK_5_EXTRAS).fill("Error: PROMISE");
     const errs = obj.stderr.match(/(^Error\: PROMISE)/gm);
     expect(errs).to.eql(exps);
   });
 });
 
+describe("production", function () {
+  // Set higher timeout for exec'ed tests.
+  this.timeout(5000); // eslint-disable-line no-invalid-this,no-magic-numbers
+
+  // Regression test: https://github.com/FormidableLabs/webpack-stats-plugin/issues/91
+  it("works in production mode", async () => {
+    // Use builder to concurrently run:
+    // `webpack<VERS>
+    const obj = await spawn(builderCli,
+      [
+        "envs", "test:build:single",
+        JSON.stringify([{ VERS: 4 }, { VERS: 5 }]),
+        "--env", JSON.stringify({ MODE: "production",
+          OUTPUT_PATH: "build-prod" }),
+        "--buffer"
+      ]
+    );
+
+    expect(obj.stderr).to.equal(null);
+    expect(obj.code).to.equal(0);
+  });
+});
+
 // Specific tests.
 describe("fixtures", () => {
   describe("webpack5", () => {
@@ -289,6 +316,17 @@ describe("fixtures", () => {
   describe("builds", () => {
     WEBPACKS.forEach((webpack) => {
       describe(webpack, () => {
+        it("creates expected files list", () => {
+          const expectedFiles = Object.keys(expecteds).sort();
+          let actualFiles = Object.keys(actuals[webpack]).sort();
+          // Remove webpack5-only files.
+          if (webpack === "webpack5") {
+            actualFiles = actualFiles.filter((file) => file !== "build/stats-contenthash.json");
+          }
+
+          expect(actualFiles).to.eql(expectedFiles);
+        });
+
         Object.keys(expecteds).forEach((name) => {
           it(`matches expected file: ${name}`, () => {
             const actual = actuals[webpack][name];
